I completed a quick test to see the possible impact of this change for the largest Discourse instance I have to hand.
root@forum:/var/discourse/shared/standalone/backups/default# time -p sh -c "gzip -cd example-com-2016-01-11-033541.tar.gz | gzip > example-com-2016-01-11-033541-recompressed-nochange.tar.gz"
real 671.66
user 637.36
sys 60.42
root@forum:/var/discourse/shared/standalone/backups/default# time -p sh -c "gzip -cd example-com-2016-01-11-033541.tar.gz | gzip --rsyncable > example-com-2016-01-11-033541-recompressed-resyncable.tar.gz"
real 748.85
user 716.44
sys 61.82
root@forum:/var/discourse/shared/standalone/backups/default# ls -l
-rw-r--r-- 1 root root 8712395243 Jan 11 00:01 example-com-2016-01-11-033541-recompressed-nochange.tar.gz
-rw-r--r-- 1 root root 8726238790 Jan 11 00:14 example-com-2016-01-11-033541-recompressed-resyncable.tar.gz
-rw-r--r-- 1 1000 www-data 8712395272 Jan 10 22:41 example-com-2016-01-11-033541.tar.gz
By adding --rsyncable it took an additional 77.19 seconds to compress the file and increased output file size by 13,843,547 bytes or approximately 13.84 MB for no real gain for me.
Perhaps not worrisome as this is background process - just thought is was worth testing.